@@ -262,16 +262,16 @@ class ZoneConditioning(UmiBase):
         self.HeatingSchedule = HeatingSchedule
         self.CoolingSchedule = CoolingSchedule
         self.CoolingCoeffOfPerf = CoolingCoeffOfPerf
-        self.CoolingLimitType = IdealSystemLimit(CoolingLimitType)
-        self.CoolingFuelType = FuelType(CoolingFuelType)
+        self.CoolingLimitType = CoolingLimitType
+        self.CoolingFuelType = CoolingFuelType
         self._cooling_setpoint = CoolingSetpoint  # setter without check
-        self.EconomizerType = EconomizerTypes(EconomizerType)
+        self.EconomizerType = EconomizerType
         self.HeatRecoveryEfficiencyLatent = HeatRecoveryEfficiencyLatent
         self.HeatRecoveryEfficiencySensible = HeatRecoveryEfficiencySensible
-        self.HeatRecoveryType = HeatRecoveryTypes(HeatRecoveryType)
+        self.HeatRecoveryType = HeatRecoveryType
         self.HeatingCoeffOfPerf = HeatingCoeffOfPerf
-        self.HeatingLimitType = IdealSystemLimit(HeatingLimitType)
-        self.HeatingFuelType = FuelType(HeatingFuelType)
+        self.HeatingLimitType = HeatingLimitType
+        self.HeatingFuelType = HeatingFuelType
         self.HeatingSetpoint = HeatingSetpoint
         self.IsCoolingOn = IsCoolingOn
         self.IsHeatingOn = IsHeatingOn
@@ -285,6 +285,9 @@ class ZoneConditioning(UmiBase):
 
         self.area = area
 
+        # Only at the end append self to CREATED_OBJECTS
+        self.CREATED_OBJECTS.append(self)
+
     @property
     def area(self):
         """Get or set the area of the zone associated to this object [m²]."""
@@ -304,7 +307,7 @@ class ZoneConditioning(UmiBase):
         assert (
             self._heating_setpoint < value
         ), "Heating setpoint must be lower than the cooling setpoint."
-        self._cooling_setpoint = validators.float(value, minimum=-100, maximum=50)
+        self._cooling_setpoint = validators.float(value, minimum=-100, maximum=100)
 
     @property
     def HeatingSetpoint(self):
@@ -316,7 +319,7 @@ class ZoneConditioning(UmiBase):
         assert (
             value < self._cooling_setpoint
         ), "Heating setpoint must be lower than the cooling setpoint."
-        self._heating_setpoint = validators.float(value)
+        self._heating_setpoint = validators.float(value, minimum=-100, maximum=100)
 
     @property
     def MaxCoolFlow(self):
@@ -413,7 +416,7 @@ class ZoneConditioning(UmiBase):
             )
             self._heating_limit_type = IdealSystemLimit[value]
         elif checkers.is_numeric(value):
-            assert IdealSystemLimit[value], (
+            assert IdealSystemLimit(value), (
                 f"Input value error for '{value}'. "
                 f"Expected one of {tuple(a for a in IdealSystemLimit)}"
             )
@@ -435,7 +438,7 @@ class ZoneConditioning(UmiBase):
             )
             self._heating_fuel_type = FuelType[value]
         elif checkers.is_numeric(value):
-            assert FuelType[value], (
+            assert FuelType(value), (
                 f"Input value error for '{value}'. "
                 f"Expected one of {tuple(a for a in FuelType)}"
             )
@@ -493,7 +496,7 @@ class ZoneConditioning(UmiBase):
             )
             self._cooling_limit_type = IdealSystemLimit[value]
         elif checkers.is_numeric(value):
-            assert IdealSystemLimit[value], (
+            assert IdealSystemLimit(value), (
                 f"Input value error for '{value}'. "
                 f"Expected one of {tuple(a for a in IdealSystemLimit)}"
             )
@@ -515,7 +518,7 @@ class ZoneConditioning(UmiBase):
             )
             self._cooling_fuel_type = FuelType[value]
         elif checkers.is_numeric(value):
-            assert FuelType[value], (
+            assert FuelType(value), (
                 f"Input value error for '{value}'. "
                 f"Expected one of {tuple(a for a in FuelType)}"
             )
@@ -559,7 +562,7 @@ class ZoneConditioning(UmiBase):
             )
             self._economizer_type = EconomizerTypes[value]
         elif checkers.is_numeric(value):
-            assert EconomizerTypes[value], (
+            assert EconomizerTypes(value), (
                 f"Input value error for '{value}'. "
                 f"Expected one of {tuple(a for a in EconomizerTypes)}"
             )
@@ -595,7 +598,7 @@ class ZoneConditioning(UmiBase):
             )
             self._heat_recovery_type = HeatRecoveryTypes[value]
         elif checkers.is_numeric(value):
-            assert HeatRecoveryTypes[value], (
+            assert HeatRecoveryTypes(value), (
                 f"Input value error for '{value}'. "
                 f"Expected one of {tuple(a for a in HeatRecoveryTypes)}"
             )
@@ -1195,9 +1198,9 @@ class ZoneConditioning(UmiBase):
                     )
                 else:
                     cooling_sched = None
-        self.HeatingSetpoint = max(h_array)[0]
+        self.HeatingSetpoint = h_array.mean()
         self.HeatingSchedule = heating_sched
-        self.CoolingSetpoint = min(c_array)[0]
+        self.CoolingSetpoint = c_array.mean()
         self.CoolingSchedule = cooling_sched
 
         # If HeatingSetpoint == nan, means there is no heat or cold input,
@@ -1583,9 +1586,7 @@ class ZoneConditioning(UmiBase):
 
     def __hash__(self):
         """Return the hash value of self."""
-        return hash(
-            (self.__class__.__name__, getattr(self, "Name", None), self.DataSource)
-        )
+        return hash(self.id)
 
     def __eq__(self, other):
         """Assert self is equivalent to other."""
@@ -1624,3 +1625,7 @@ class ZoneConditioning(UmiBase):
     def __copy__(self):
         """Create a copy of self."""
         return self.__class__(**self.mapping(validate=False))
+
+    @property
+    def children(self):
+        return self.CoolingSchedule, self.HeatingSchedule, self.MechVentSchedule
