@@ -126,11 +126,14 @@ class ZoneLoad(UmiBase):
         self.IsEquipmentOn = IsEquipmentOn
         self.IsLightingOn = IsLightingOn
         self.IsPeopleOn = IsPeopleOn
-        self.DimmingType = DimmingTypes(DimmingType)
+        self.DimmingType = DimmingType
         self.IlluminanceTarget = IlluminanceTarget
         self.area = area
         self.volume = volume
 
+        # Only at the end append self to CREATED_OBJECTS
+        self.CREATED_OBJECTS.append(self)
+
     @property
     def DimmingType(self):
         """Get or set the dimming type.
@@ -151,7 +154,7 @@ class ZoneLoad(UmiBase):
             )
             self._dimming_type = DimmingTypes[value]
         elif checkers.is_numeric(value):
-            assert DimmingTypes[value], (
+            assert DimmingTypes(value), (
                 f"Input value error for '{value}'. "
                 f"Expected one of {tuple(a for a in DimmingTypes)}"
             )
@@ -808,9 +811,7 @@ class ZoneLoad(UmiBase):
 
     def __hash__(self):
         """Return the hash value of self."""
-        return hash(
-            (self.__class__.__name__, getattr(self, "Name", None), self.DataSource)
-        )
+        return hash(self.id)
 
     def __key__(self):
         """Get a tuple of attributes. Useful for hashing and comparing."""
@@ -835,6 +836,14 @@ class ZoneLoad(UmiBase):
         else:
             return self.__key__() == other.__key__()
 
+    @property
+    def children(self):
+        return (
+            self.EquipmentAvailabilitySchedule,
+            self.LightsAvailabilitySchedule,
+            self.OccupancySchedule,
+        )
+
 
 def _resolve_dimming_type(zone, zone_ep):
     """Resolve the dimming type for the Zone object.
