@@ -92,8 +92,6 @@ class UmiBase(object):
         self.unit_number = next(self._ids)
         self.predecessors = None
 
-        UmiBase.CREATED_OBJECTS.append(self)
-
     @property
     def Name(self):
         """Get or set the name of the object."""
@@ -180,6 +178,10 @@ class UmiBase(object):
     def predecessors(self, value):
         self._predecessors = value
 
+    @property
+    def children(self):
+        return ()
+
     def duplicate(self):
         """Get copy of self."""
         return self.__copy__()
@@ -251,7 +253,7 @@ class UmiBase(object):
 
     def __hash__(self):
         """Return the hash value of self."""
-        return hash((self.__class__.mro()[0].__name__, self.Name))
+        return hash(self.id)
 
     def __repr__(self):
         """Return a representation of self."""
@@ -266,6 +268,12 @@ class UmiBase(object):
         for attr, value in self.mapping().items():
             yield attr, value
 
+    def __getitem__(self, item):
+        return getattr(self, item)
+
+    def __setitem__(self, key, value):
+        setattr(self, key, value)
+
     def __copy__(self):
         """Create a copy of self."""
         return self.__class__(**self.mapping(validate=False))
@@ -395,7 +403,7 @@ class UmiBase(object):
             self.validate()
 
         return dict(
-            id=self.id,
+            # id=self.id,
             Name=self.Name,
             Category=self.Category,
             Comments=self.Comments,
