@@ -123,14 +123,17 @@ class WindowSetting(UmiBase):
         self.OperableArea = OperableArea
         self.ShadingSystemSetpoint = ShadingSystemSetpoint
         self.ShadingSystemTransmittance = ShadingSystemTransmittance
-        self.ShadingSystemType = ShadingType(ShadingSystemType)
-        self.Type = WindowType(Type)
+        self.ShadingSystemType = ShadingSystemType
+        self.Type = Type
         self.ZoneMixingDeltaTemperature = ZoneMixingDeltaTemperature
         self.ZoneMixingFlowRate = ZoneMixingFlowRate
         self.ZoneMixingAvailabilitySchedule = ZoneMixingAvailabilitySchedule
 
         self.area = area
 
+        # Only at the end append self to CREATED_OBJECTS
+        self.CREATED_OBJECTS.append(self)
+
     @property
     def area(self):
         """Get or set the area of the zone associated to this object [m²]."""
@@ -195,7 +198,7 @@ class WindowSetting(UmiBase):
             )
             self._shading_system_type = ShadingType[value]
         elif checkers.is_numeric(value):
-            assert ShadingType[value], (
+            assert ShadingType(value), (
                 f"Input value error for '{value}'. "
                 f"Expected one of {tuple(a for a in ShadingType)}"
             )
@@ -336,7 +339,7 @@ class WindowSetting(UmiBase):
             )
             self._type = WindowType[value]
         elif checkers.is_numeric(value):
-            assert WindowType[value], (
+            assert WindowType(value), (
                 f"Input value error for '{value}'. "
                 f"Expected one of {tuple(a for a in WindowType)}"
             )
@@ -358,9 +361,7 @@ class WindowSetting(UmiBase):
 
     def __hash__(self):
         """Return the hash value of self."""
-        return hash(
-            (self.__class__.__name__, getattr(self, "Name", None), self.DataSource)
-        )
+        return hash(self.id)
 
     def __eq__(self, other):
         """Assert self is equivalent to other."""
@@ -913,3 +914,12 @@ class WindowSetting(UmiBase):
             DataSource=self.DataSource,
             Name=self.Name,
         )
+
+    @property
+    def children(self):
+        return (
+            self.AfnWindowAvailability,
+            self.Construction,
+            self.ShadingSystemAvailabilitySchedule,
+            self.ZoneMixingAvailabilitySchedule,
+        )
