@@ -4,7 +4,9 @@ import json
 import logging as lg
 from collections import OrderedDict
 from concurrent.futures.thread import ThreadPoolExecutor
+from typing import List
 
+import networkx as nx
 from pandas.io.common import get_handle
 from path import Path
 
@@ -24,6 +26,7 @@ from archetypal.template.materials.material_layer import MaterialLayer
 from archetypal.template.materials.opaque_material import OpaqueMaterial
 from archetypal.template.schedule import (
     DaySchedule,
+    UmiSchedule,
     WeekSchedule,
     YearSchedule,
     YearSchedulePart,
@@ -144,6 +147,24 @@ class UmiTemplateLibrary:
         for group in self._LIB_GROUPS:
             yield group, self.__dict__[group]
 
+    def __getitem__(self, item):
+        return self.__dict__[item]
+
+    def __add__(self, other: "UmiTemplateLibrary"):
+        """Combined"""
+        for key, group in other:
+            # for each group items
+            for component in group:
+                component.id = None  # Reset the component's id
+
+        attrs = {}
+        for group, value in self:
+            attrs[group] = value + other.__dict__[group]
+
+        newlib = self.__class__(**attrs, name=self.name)
+        newlib.unique_components("GasMaterials", keep_orphaned=True)
+        return newlib
+
     def _clear_components_list(self, except_groups=None):
         """Clear components lists except except_groups."""
         if except_groups is None:
@@ -154,6 +175,14 @@ class UmiTemplateLibrary:
             if key not in exception:
                 setattr(self, key, [])
 
+    @property
+    def object_list(self):
+        """Get list of all objects in self, including orphaned objects."""
+        objs = []
+        for name, group in self:
+            objs.extend(group)
+        return objs
+
     @classmethod
     def from_idf_files(
         cls,
@@ -162,6 +191,8 @@ class UmiTemplateLibrary:
         name="unnamed",
         processors=-1,
         keep_all_zones=False,
+        unique_components=None,
+        debug=False,
         **kwargs,
     ):
         """Initialize an UmiTemplateLibrary object from one or more idf_files.
@@ -178,6 +209,7 @@ class UmiTemplateLibrary:
             weather (str or Path): Path to the weather file.
             name (str): The name of the Template File
             processors (int): Number of cores. Defaults to -1, all cores.
+            debug (bool): If True, will raise any error on any processed file.
             kwargs: keyword arguments passed to IDF().
 
         Raises:
@@ -205,32 +237,37 @@ class UmiTemplateLibrary:
             cls.template_complexity_reduction,
             processors=processors,
             use_kwargs=True,
-            debug=True,
+            debug=debug,
             position=None,
             executor=ThreadPoolExecutor,
         )
-        for res in results:
+        for filename, res in results.items():
             if isinstance(res, EnergyPlusProcessError):
                 filename = (settings.logs_folder / "failed_reduce.txt").expand()
                 with open(filename, "a") as file:
                     file.writelines(res.write())
-                    log(f"EnergyPlusProcess errors listed in {filename}")
+                    log(
+                        f"EnergyPlusProcess error for {filename} listed in"
+                        f" {filename}: {res}",
+                        lg.ERROR,
+                    )
             elif isinstance(res, Exception):
-                if settings.debug:
+                if debug:
                     raise res
                 else:
                     log(
-                        f"Unable to create Building Template. Exception raised: "
-                        f"{str(res)}",
+                        f"Exception raised for {filename}: {res}",
                         lg.ERROR,
                     )
 
         # If all exceptions, raise them for debugging
-        if all(isinstance(x, Exception) for x in results):
-            raise Exception([res for res in results if isinstance(res, Exception)])
+        if all(isinstance(x, Exception) for x in results.values()):
+            raise Exception(
+                [res for res in results.values() if isinstance(res, Exception)]
+            )
 
         umi_template.BuildingTemplates = [
-            res for res in results if not isinstance(res, Exception)
+            res for res in results.values() if not isinstance(res, Exception)
         ]
 
         if keep_all_zones:
@@ -246,7 +283,9 @@ class UmiTemplateLibrary:
             exceptions = None
 
         # Get unique instances
-        umi_template.unique_components(exceptions)
+        umi_template.unique_components(
+            *(unique_components or []), exceptions=exceptions
+        )
 
         # Update attributes of instance
         umi_template.update_components_list(exceptions=exceptions)
@@ -272,8 +311,10 @@ class UmiTemplateLibrary:
         for day in idf.idfobjects["RunPeriodControl:SpecialDays".upper()]:
             idf.removeidfobject(day)
 
-        if idf.sim_info is None:
+        try:
             idf.simulate()
+        except EnergyPlusProcessError as e:
+            return e
         return BuildingTemplate.from_idf(idf, **kwargs)
 
     @classmethod
@@ -606,26 +647,65 @@ class UmiTemplateLibrary:
 
         return data_dict
 
-    def unique_components(self, exceptions=None):
+    def unique_components(
+        self, *args: str, exceptions: List[str] = None, keep_orphaned=False
+    ):
         """Keep only unique components.
 
+        Starts by clearing all objects in self except self.BuildingTemplates.
+        Then, recursively traverses the children of each BuildingTemplate, finding a
+        unique object for "equivalent" components.
+
         Calls :func:`~archetypal.template.umi_base.UmiBase.get_unique` for each
         object in the graph.
+
+        Args:
+            *args (str): UmiBase class names that should be replaced with a
+                unique equivalent. For example, if only "OpaqueMaterials" should be
+                unique, then use self.unique_components("OpaqueMaterials"). If none
+                are provided, all umi components be unique.
+            exceptions (List[str]): A list of UmiBase class names that will not be
+                cleared from self.
+            keep_orphaned (bool): if True, orphaned objects are kept.
         """
+        if keep_orphaned:
+            G = self.to_graph(include_orphans=True)
+            connected_to_building = set()
+            for bldg in self.BuildingTemplates:
+                for obj in nx.dfs_preorder_nodes(G, bldg):
+                    connected_to_building.add(obj)
+            orphans = [
+                obj for obj in self.object_list if obj not in connected_to_building
+            ]
         self._clear_components_list(exceptions)  # First clear components
 
+        # Inclusion is a set of object classes that will be unique.
+        inclusion = set(args or [])
+        if not inclusion.isdisjoint(set(self._LIB_GROUPS)):
+            inclusion = set(self._LIB_GROUPS).intersection(inclusion)
+        else:
+            if inclusion:
+                assert inclusion.intersection(set(self._LIB_GROUPS)), (
+                    f"{', '.join(inclusion.difference(set(self._LIB_GROUPS)))} not a "
+                    f"valid class name. Valid values are: "
+                    f"{', '.join(set(self._LIB_GROUPS))}"
+                )
+            inclusion = set(self._LIB_GROUPS)
         for key, group in self:
             # for each group
             for component in group:
                 # travers each object using generator
-                for parent, key, obj in traverse(component):
-                    if key:  # key is None when we reach lowest level
-                        setattr(
-                            parent, key, obj.get_unique()
-                        )  # set unique object on key
+                for parent, key, obj in parent_key_child_traversal(component):
+                    if obj.__class__.__name__ + "s" in inclusion:
+                        if key:
+                            setattr(
+                                parent, key, obj.get_unique()
+                            )  # set unique object on key
 
         self.update_components_list(exceptions=exceptions)  # Update the components list
-        # that was cleared
+        if keep_orphaned:
+            for obj in orphans:
+                self[obj.__class__.__name__ + "s"].append(obj)
 
     def replace_component(self, this, that) -> None:
         """Replace all instances of `this` with `that`.
@@ -635,7 +715,7 @@ class UmiTemplateLibrary:
             that (UmiBase): The object to replace each references with.
         """
         for bldg in self.BuildingTemplates:
-            for parent, key, obj in traverse(bldg):
+            for parent, key, obj in parent_key_child_traversal(bldg):
                 if obj is this:
                     setattr(parent, key, that)
 
@@ -648,22 +728,51 @@ class UmiTemplateLibrary:
 
         for key, group in self:
             for component in group:
-                for parent, key, child in traverse(component):
-                    if isinstance(child, UmiBase):
+                for parent, key, child in parent_key_child_traversal(component):
+                    if isinstance(child, UmiSchedule) and not isinstance(
+                        child, (DaySchedule, WeekSchedule, YearSchedule)
+                    ):
+                        y, ws, ds = child.to_year_week_day()
+                        if not any(o.id == y.id for o in self.YearSchedules):
+                            self.YearSchedules.append(y)
+                        for w in ws:
+                            if not any(o.id == w.id for o in self.WeekSchedules):
+                                self.WeekSchedules.append(w)
+                        for d in ds:
+                            if not any(o.id == d.id for o in self.DaySchedules):
+                                self.DaySchedules.append(d)
+                        # finally, replace it with y
+                        setattr(parent, key, y)
+                    elif isinstance(child, UmiBase):
                         obj_list = self.__dict__[child.__class__.__name__ + "s"]
                         if not any(o.id == child.id for o in obj_list):
                             # Important to compare on UmiBase.id and not on identity.
                             obj_list.append(child)
 
-    def build_graph(self):
-        """Create the :class:`networkx.DiGraph` UmiBase objects as nodes."""
+    def to_graph(self, include_orphans=False):
+        """Create a :class:`networkx.DiGraph` of self.
+
+        This networkx.DiGraph object is then useful for graph-theory operations on
+        the hierarchy of the UmiTemplateLibrary.
+        """
         import networkx as nx
 
         G = nx.DiGraph()
 
         for bldg in self.BuildingTemplates:
-            for parent, key, child in traverse(bldg):
-                G.add_edge(parent, child)
+            for parent, child in parent_child_traversal(bldg):
+                if parent:
+                    G.add_edge(parent, child)
+
+        if include_orphans:
+            orphans = [
+                obj for obj in self.object_list if obj.id not in (n.id for n in G)
+            ]
+            for orphan in orphans:
+                G.add_node(orphan)
+                for parent, child in parent_child_traversal(orphan):
+                    if parent:
+                        G.add_edge(parent, child)
 
         return G
 
@@ -715,16 +824,18 @@ def no_duplicates(file, attribute="Name"):
 DEEP_OBJECTS = (UmiBase, MaterialLayer, GasLayer, YearSchedulePart, MassRatio, list)
 
 
-def traverse(parent):
-    """Iterate over UmiBases in a depth-first-search (DFS).
+def parent_key_child_traversal(parent):
+    """Iterate over children of parent yield the parent, the attribute name of the
+    children (key) and the children itself.
 
-    Perform a depth-first-search over the UmiBase objects of var and
-    yield the Umibase objects in order.
+    If called on a :class:BuildingTemplate object, this will traverse all the
+    umi components this object references, like a depth-first search algotrithm in a
+    graph structure.
     """
     if isinstance(parent, DEEP_OBJECTS):
         if isinstance(parent, list):
             for obj in parent:
-                yield from traverse(obj)
+                yield from parent_key_child_traversal(obj)
         elif isinstance(parent, DaySchedule):
             yield None, None, parent
         else:
@@ -732,4 +843,20 @@ def traverse(parent):
                 if isinstance(child, UmiBase):
                     yield parent, k, child
                 if isinstance(child, DEEP_OBJECTS):
-                    yield from traverse(child)
+                    yield from parent_key_child_traversal(child)
+
+
+def parent_child_traversal(parent: UmiBase):
+    """Iterate over all children of the parent.
+
+    This generator recursively yields (parent, child) tuples. It uses the
+    :attr:`UmiBase.children` attribute and had a better performance than
+    :func:`parent_key_child_traversal`.
+    """
+    for child in parent.children:
+        yield parent, child
+        yield from parent_child_traversal(child)
+
+
+def traverse(parent):
+    return parent_child_traversal(parent)
